#!/bin/sh 
# test the state of the mounted filesystems
#
# Tim Hockin

. /usr/sausalito/swatch/statecodes

msg=""

function addmsg {
	[ $# = 1 ] || return -1

	if [ "$msg" ]; then
		msg="$msg\n"
	fi
	msg="$msg$1"
}

# set defaults
if [ -z $red_free ]; then
	red_free="200"
fi
if [ -z $red_pcnt ]; then
	red_pcnt="95"
fi
if [ -z $yellow_free ]; then
	yellow_free="400"
fi
if [ -z $yellow_pcnt ]; then
	yellow_pcnt="90"
fi

# we may change this later
FINAL_RET=$AM_STATE_GREEN

# acquire data
df | egrep "^/dev/" | (
while read DEV SIZE USED AVAIL PCNT MNT; do
	# check that it is r/w
	grep "^$DEV" /etc/mtab | awk '$4 ~ /^rw/ { exit 1 }'
	if [ "$?" = 0 ]; then
		continue;
	fi
		
	# use bc (not bc -l) so we don't get a floating point 
	AVAIL=`echo "$AVAIL / 1024" | bc`
	PCNT=`echo "$USED * 100 / $SIZE" | bc`

	# decide
	if [ $AVAIL -lt $red_free ]; then
		addmsg "[[base-disk.amDiskWarning,fs=$MNT,pcnt=$PCNT,free=$AVAIL]]"
		FINAL_RET=$AM_STATE_RED
		continue
	fi

	if [ $AVAIL -lt $yellow_free ]; then
		addmsg "[[base-disk.amDiskWarning,fs=$MNT,pcnt=$PCNT,free=$AVAIL]]"
		if [ "$FINAL_RET" != "$AM_STATE_RED" ]; then
			FINAL_RET=$AM_STATE_YELLOW
		fi
	fi
done

if [ "$FINAL_RET" = "$AM_STATE_GREEN" ]; then
	echo -ne "[[base-disk.amDiskOk]]"
else
	echo -ne "$msg"
fi

exit $FINAL_RET
)

exit $?
